=======
GPS API
=======


.. image:: https://img.shields.io/pypi/v/gps_api.svg
        :target: https://pypi.python.org/pypi/gps_api

.. image:: https://img.shields.io/travis/jialong-w/gps_api.svg
        :target: https://travis-ci.com/jialong-w/gps_api

.. image:: https://readthedocs.org/projects/gps-api/badge/?version=latest
        :target: https://gps-api.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




UNIVERSITY OF CAPE TOWN, EEE3097S 2020, Engineering Design: ECE, Design Project: API for Grove-GPS (Air530).


* Free software: MIT license
* Documentation: https://gps-api.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
